@@ -8,6 +8,7 @@ under the terms of the Creative Commons Attribution-NonCommercial
 The code is licensed under the MIT license.
 """
 
+import os
 from math import cos, sqrt, radians
 from copy import copy
 from datetime import datetime, timedelta
@@ -26,7 +27,7 @@ class Stations(Core):
     cache_subdir: str = 'stations'
 
     # The list of selected weather Stations
-    _stations = None
+    stations = None
 
     # Raw data columns
     _columns: list = [
@@ -69,7 +70,7 @@ class Stations(Core):
         """
 
         # File name
-        file = 'lib.csv.gz'
+        file = 'stations/lib.csv.gz'
 
         # Get local file path
         path = self._get_file_path(self.cache_subdir, file)
@@ -84,7 +85,7 @@ class Stations(Core):
 
             # Get data from Meteostat
             df = self._load_handler(
-                'stations/' + file,
+                file,
                 self._columns,
                 self._types,
                 self._parse_dates,
@@ -98,7 +99,7 @@ class Stations(Core):
                 df.to_pickle(path)
 
         # Set data
-        self._stations = df
+        self.stations = df
 
     def __init__(self) -> None:
 
@@ -125,9 +126,9 @@ class Stations(Core):
             code = [code]
 
         if organization == 'meteostat':
-            temp._stations = temp._stations[temp._stations.index.isin(code)]
+            temp.stations = temp.stations[temp.stations.index.isin(code)]
         else:
-            temp._stations = temp._stations[temp._stations[organization].isin(
+            temp.stations = temp.stations[temp.stations[organization].isin(
                 code)]
 
         # Return self
@@ -158,16 +159,16 @@ class Stations(Core):
             return radius * sqrt(x * x + y * y)
 
         # Get distance for each stationsd
-        temp._stations['distance'] = temp._stations.apply(
+        temp.stations['distance'] = temp.stations.apply(
             lambda station: distance(station, [lat, lon]), axis=1)
 
         # Filter by radius
         if radius is not None:
-            temp._stations = temp._stations[temp._stations['distance'] <= radius]
+            temp.stations = temp.stations[temp.stations['distance'] <= radius]
 
         # Sort stations by distance
-        temp._stations.columns.str.strip()
-        temp._stations = temp._stations.sort_values('distance')
+        temp.stations.columns.str.strip()
+        temp.stations = temp.stations.sort_values('distance')
 
         # Return self
         return temp
@@ -185,11 +186,11 @@ class Stations(Core):
         temp = copy(self)
 
         # Country code
-        temp._stations = temp._stations[temp._stations['country'] == country]
+        temp.stations = temp.stations[temp.stations['country'] == country]
 
         # State code
         if state is not None:
-            temp._stations = temp._stations[temp._stations['region'] == state]
+            temp.stations = temp.stations[temp.stations['region'] == state]
 
         # Return self
         return temp
@@ -207,11 +208,11 @@ class Stations(Core):
         temp = copy(self)
 
         # Return stations in boundaries
-        temp._stations = temp._stations[
-            (temp._stations['latitude'] <= top_left[0]) &
-            (temp._stations['latitude'] >= bottom_right[0]) &
-            (temp._stations['longitude'] <= bottom_right[1]) &
-            (temp._stations['longitude'] >= top_left[1])
+        temp.stations = temp.stations[
+            (temp.stations['latitude'] <= top_left[0]) &
+            (temp.stations['latitude'] >= bottom_right[0]) &
+            (temp.stations['longitude'] <= bottom_right[1]) &
+            (temp.stations['longitude'] >= top_left[1])
         ]
 
         # Return self
@@ -231,27 +232,27 @@ class Stations(Core):
 
         if required is True:
             # Make sure data exists at all
-            temp._stations = temp._stations[
-                (pd.isna(temp._stations[granularity + '_start']) == False)
+            temp.stations = temp.stations[
+                (pd.isna(temp.stations[granularity + '_start']) == False)
             ]
         elif isinstance(required, tuple):
             # Make sure data exists across period
-            temp._stations = temp._stations[
-                (pd.isna(temp._stations[granularity + '_start']) == False) &
-                (temp._stations[granularity + '_start'] <= required[0]) &
+            temp.stations = temp.stations[
+                (pd.isna(temp.stations[granularity + '_start']) == False) &
+                (temp.stations[granularity + '_start'] <= required[0]) &
                 (
-                    temp._stations[granularity + '_end'] +
+                    temp.stations[granularity + '_end'] +
                     timedelta(seconds=temp.max_age)
                     >= required[1]
                 )
             ]
         else:
             # Make sure data exists on a certain day
-            temp._stations = temp._stations[
-                (pd.isna(temp._stations[granularity + '_start']) == False) &
-                (temp._stations[granularity + '_start'] <= required) &
+            temp.stations = temp.stations[
+                (pd.isna(temp.stations[granularity + '_start']) == False) &
+                (temp.stations[granularity + '_start'] <= required) &
                 (
-                    temp._stations[granularity + '_end'] +
+                    temp.stations[granularity + '_end'] +
                     timedelta(seconds=temp.max_age)
                     >= required
                 )
@@ -272,8 +273,8 @@ class Stations(Core):
 
         # Change data units
         for parameter, unit in units.items():
-            if parameter in temp._stations.columns.values:
-                temp._stations[parameter] = temp._stations[parameter].apply(
+            if parameter in temp.stations.columns.values:
+                temp.stations[parameter] = temp.stations[parameter].apply(
                     unit)
 
         # Return class instance
@@ -284,7 +285,7 @@ class Stations(Core):
         Return number of weather stations in current selection
         """
 
-        return len(self._stations.index)
+        return len(self.stations.index)
 
     def fetch(
         self,
@@ -296,7 +297,7 @@ class Stations(Core):
         """
 
         # Copy DataFrame
-        temp = copy(self._stations)
+        temp = copy(self.stations)
 
         # Return limited number of sampled entries
         if sample and limit:
